@@ -97,7 +97,7 @@ photos_main_toolbar_set_toolbar_title (PhotosMainToolbar *self)
       if (!selection_mode)
         {
           if (active_collection != NULL)
-            primary = g_markup_printf_escaped ("%s", photos_base_item_get_name (PHOTOS_BASE_ITEM (active_collection)));
+            primary = g_strdup (photos_base_item_get_name (PHOTOS_BASE_ITEM (active_collection)));
         }
       else
         {
@@ -120,7 +120,8 @@ photos_main_toolbar_set_toolbar_title (PhotosMainToolbar *self)
             }
           else
             {
-              primary = g_markup_printf_escaped ("%s", label);
+              primary = label;
+              label = NULL;
             }
 
           g_free (label);
@@ -132,7 +133,7 @@ photos_main_toolbar_set_toolbar_title (PhotosMainToolbar *self)
 
       item = photos_base_manager_get_active_object (priv->item_mngr);
       if (item != NULL)
-        primary = g_markup_printf_escaped ("%s", photos_base_item_get_name (PHOTOS_BASE_ITEM (item)));
+        primary = g_strdup (photos_base_item_get_name (PHOTOS_BASE_ITEM (item)));
     }
 
   if (selection_mode)
